@@ -3,7 +3,7 @@
 		integrate over the unit hypercube
 		this file is part of Suave
 		checkpointing by B. Chokoufe
-		last modified 18 Apr 14 th
+		last modified 24 Apr 14 th
 */
 
 
@@ -37,7 +37,7 @@ static int Integrate(This *t, real *integral, real *error, real *prob)
       "  flags %d\n  seed %d\n"
       "  mineval " NUMBER "\n  maxeval " NUMBER "\n"
       "  nnew " NUMBER "\n  flatness " REAL "\n"
-      "  statefile \"%s\"\n",
+      "  statefile \"%s\"",
       t->ndim, t->ncomp,
       ML_NOT(t->nvec,)
       t->epsrel, t->epsabs,
@@ -51,8 +51,7 @@ static int Integrate(This *t, real *integral, real *error, real *prob)
   if( BadComponent(t) ) return -2;
   if( BadDimension(t) ) return -1;
 
-  InitWorker(t);
-  ShmAlloc(t, ShmRm(t));
+  ShmAlloc(t, Master);
   ForkCores(t);
 
   if( (fail = setjmp(t->abort)) ) goto abort;
@@ -341,11 +340,9 @@ abort:
     anchor = anchor->next;
     free(region);
   }
-  WaitCores(t);
-  ShmFree(t);
+  ShmFree(t, Master);
 
   StateRemove(t);
-  ExitWorker(t);
 
   return fail;
 }
