@@ -1,8 +1,8 @@
 /*
 	Suave.c
-		Subregion-adaptive Vegas Monte-Carlo integration
+		Subregion-adaptive Vegas Monte Carlo integration
 		by Thomas Hahn
-		last modified 9 Dec 13 th
+		last modified 25 Nov 14 th
 */
 
 
@@ -20,11 +20,14 @@ Extern void EXPORT(Suave)(ccount ndim, ccount ncomp,
   cint flags, cint seed,
   cnumber mineval, cnumber maxeval,
   cnumber nnew, creal flatness,
-  cchar *statefile,
+  cchar *statefile, Spin **pspin,
   count *pnregions, number *pneval, int *pfail,
   real *integral, real *error, real *prob)
 {
   This t;
+
+  VerboseInit();
+
   t.ndim = ndim;
   t.ncomp = ncomp;
   t.integrand = integrand;
@@ -32,17 +35,20 @@ Extern void EXPORT(Suave)(ccount ndim, ccount ncomp,
   t.nvec = nvec;
   t.epsrel = epsrel;
   t.epsabs = epsabs;
-  t.flags = flags;
+  t.flags = MaxVerbose(flags);
   t.seed = seed;
   t.mineval = mineval;
   t.maxeval = maxeval;
   t.nnew = nnew;
   t.flatness = flatness;
   t.statefile = statefile;
+  FORK_ONLY(t.spin = Invalid(pspin) ? NULL : *pspin;)
 
   *pfail = Integrate(&t, integral, error, prob);
   *pnregions = t.nregions;
   *pneval = t.neval;
+
+  WaitCores(&t, pspin);
 }
 
 /*********************************************************************/
@@ -53,11 +59,14 @@ Extern void EXPORT(suave)(ccount *pndim, ccount *pncomp,
   cint *pflags, cint *pseed,
   cnumber *pmineval, cnumber *pmaxeval,
   cnumber *pnnew, creal *pflatness,
-  cchar *statefile,
+  cchar *statefile, Spin **pspin,
   count *pnregions, number *pneval, int *pfail,
   real *integral, real *error, real *prob, cint statefilelen)
 {
   This t;
+
+  VerboseInit();
+
   t.ndim = *pndim;
   t.ncomp = *pncomp;
   t.integrand = integrand;
@@ -65,16 +74,19 @@ Extern void EXPORT(suave)(ccount *pndim, ccount *pncomp,
   t.nvec = *pnvec;
   t.epsrel = *pepsrel;
   t.epsabs = *pepsabs;
-  t.flags = *pflags;
+  t.flags = MaxVerbose(*pflags);
   t.seed = *pseed;
   t.mineval = *pmineval;
   t.maxeval = *pmaxeval;
   t.nnew = *pnnew;
   t.flatness = *pflatness;
   CString(t.statefile, statefile, statefilelen);
+  FORK_ONLY(t.spin = Invalid(pspin) ? NULL : *pspin;)
 
   *pfail = Integrate(&t, integral, error, prob);
   *pnregions = t.nregions;
   *pneval = t.neval;
+
+  WaitCores(&t, pspin);
 }
 
